pub enum Error {
InvalidMetadata,
InvalidRecordSize(u16),
InvalidDatabaseType(String),
InvalidSearchTreeSize,
InvalidOffset,
InvalidDataType(u8),
InvalidNode,
UnknownField(String),
NotFound,
IPv4Only,
CorruptSearchTree,
Utf8Error(Utf8Error),
}
Tuple Fields of InvalidRecordSize
Tuple Fields of InvalidDatabaseType
Tuple Fields of InvalidDataType
Tuple Fields of UnknownField
Tuple Fields of Utf8Error
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.